@@ -135,7 +135,7 @@ func (rb *Base) RunRequestsCmd(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	_, err = rb.MakeRequest(cmd.Context(), apiKey, path, &rb.Parameters, false)
+	_, err = rb.MakeRequest(cmd.Context(), apiKey, path, &rb.Parameters, false, nil)
 
 	return err
 }
@@ -203,8 +203,8 @@ func (rb *Base) MakeMultiPartRequest(ctx context.Context, apiKey, path string, p
 	return rb.performRequest(ctx, client, path, params, reqBody.String(), errOnStatus, configure)
 }
 
-// MakeRequest will make a request to the Stripe API with the specific variables given to it
-func (rb *Base) MakeRequest(ctx context.Context, apiKey, path string, params *RequestParameters, errOnStatus bool) ([]byte, error) {
+// MakeV2Request will make a application/json request to the Stripe API with the specific payload given to it.
+func (rb *Base) MakeV2Request(ctx context.Context, apiKey, path string, params *RequestParameters, errOnStatus bool, additionalConfigure func(req *http.Request) error, jsonPayload string) ([]byte, error) {
 	parsedBaseURL, err := url.Parse(rb.APIBaseURL)
 	if err != nil {
 		return []byte{}, err
@@ -216,18 +216,34 @@ func (rb *Base) MakeRequest(ctx context.Context, apiKey, path string, params *Re
 		Verbose: rb.showHeaders,
 	}
 
-	return rb.MakeRequestWithClient(ctx, client, path, params, errOnStatus)
+	return rb.performRequest(ctx, client, path, params, jsonPayload, errOnStatus, additionalConfigure)
+}
+
+// MakeRequest will make a request to the Stripe API with the specific variables given to it
+func (rb *Base) MakeRequest(ctx context.Context, apiKey, path string, params *RequestParameters, errOnStatus bool, additionalConfigure func(req *http.Request) error) ([]byte, error) {
+	parsedBaseURL, err := url.Parse(rb.APIBaseURL)
+	if err != nil {
+		return []byte{}, err
+	}
+
+	client := &stripe.Client{
+		BaseURL: parsedBaseURL,
+		APIKey:  apiKey,
+		Verbose: rb.showHeaders,
+	}
+
+	return rb.MakeRequestWithClient(ctx, client, path, params, errOnStatus, additionalConfigure)
 }
 
 // MakeRequestWithClient will make a request to the Stripe API with the specific
 // variables given to it using the provided client.
-func (rb *Base) MakeRequestWithClient(ctx context.Context, client stripe.RequestPerformer, path string, params *RequestParameters, errOnStatus bool) ([]byte, error) {
+func (rb *Base) MakeRequestWithClient(ctx context.Context, client stripe.RequestPerformer, path string, params *RequestParameters, errOnStatus bool, additionalConfigure func(req *http.Request) error) ([]byte, error) {
 	data, err := rb.BuildDataForRequest(params)
 	if err != nil {
 		return []byte{}, err
 	}
 
-	return rb.performRequest(ctx, client, path, params, data, errOnStatus, nil)
+	return rb.performRequest(ctx, client, path, params, data, errOnStatus, additionalConfigure)
 }
 
 func (rb *Base) performRequest(ctx context.Context, client stripe.RequestPerformer, path string, params *RequestParameters, data string, errOnStatus bool, additionalConfigure func(req *http.Request) error) ([]byte, error) {
@@ -240,6 +256,17 @@ func (rb *Base) performRequest(ctx context.Context, client stripe.RequestPerform
 				return err
 			}
 		}
+
+		if rb.Profile != nil {
+			experimentalFields := rb.Profile.GetExperimentalFields()
+			if experimentalFields.StripeHeaders != "" {
+				err := rb.experimentalRequestSigning(req, experimentalFields)
+				if err != nil {
+					return err
+				}
+			}
+		}
+
 		return nil
 	}
 
@@ -488,3 +515,35 @@ func normalizePath(path string) string {
 
 	return "/v1/" + path
 }
+
+func (rb *Base) experimentalRequestSigning(req *http.Request, experimentalFields config.ExperimentalFields) error {
+	privKey := experimentalFields.PrivateKey
+
+	keyToValues := strings.Split(strings.Trim(experimentalFields.StripeHeaders, ";"), ";")
+	for _, pair := range keyToValues {
+		header := strings.Split(pair, "=")
+		if len(header) != 2 {
+			continue
+		}
+		headerName := header[0]
+		headerValue := header[1]
+		if headerName == stripeContextHeaderName {
+			displayMessage := fmt.Sprintf("Operating in %s %s\n", ansi.Bold(experimentalFields.ContextualName), ansi.Color(os.Stdout).Gray(10, "("+headerValue+")..."))
+			fmt.Print(ansi.Color(os.Stdout).Gray(10, displayMessage))
+		} else if headerName == authorizationHeaderName && privKey == "" {
+			creds, err := rb.Profile.GetSessionCredentials()
+			if err != nil {
+				return err
+			}
+			headerValue += creds.UAT
+			privKey = creds.PrivateKey
+		}
+		req.Header.Set(headerName, headerValue)
+	}
+	if len(keyToValues) > 0 {
+		// Must sign the request AFTER all headers have been set
+		SignRequest(req, privKey)
+	}
+
+	return nil
+}
